# Citing

This software:
```
@software{pysr,
  author       = {Miles Cranmer},
  title        = {PySR: Fast \& Parallelized Symbolic Regression in Python/Julia},
  month        = sep,
  year         = 2020,
  publisher    = {Zenodo},
  doi          = {10.5281/zenodo.4041459},
  url          = {http://doi.org/10.5281/zenodo.4041459}
}
```

Metric used for scoring equations:
```
@article{cranmer2020discovering,
      title={Discovering Symbolic Models from Deep Learning with Inductive Biases}, 
      author={Miles Cranmer and Alvaro Sanchez-Gonzalez and Peter Battaglia and Rui Xu and Kyle Cranmer and David Spergel and Shirley Ho},
      journal={NeurIPS 2020},
      year={2020},
      eprint={2006.11287},
      archivePrefix={arXiv},
      primaryClass={cs.LG}
}
```
